% simulazione del modello SEIR
clear all; close all;

% parametri, variabile di stato e orizzonte di simulazione
global mu; global gamma; global alfa; 
global beta0; global delta;

mu=0.02; gamma=100; 
alfa=35.842;
% alfa=10*35.842;
beta0=1884.95;

opt=odeset('RelTol',1E-7,'AbsTol',1E-7);

%%%%%%%%%%%%% ciclo di periodo 1 %%%%%%%%%%%%%
delta=0.02;
Tfin=50;
x0vere=[0.5 0.01 0.01 1 0];
x0=[log(x0vere(1)) log(x0vere(2)) log(x0vere(3)) x0vere(4) x0vere(5)];
% transitorio
[tempo,x] = ode23('modello_SEIR',[0 Tfin*3],x0,opt);
% attrattore
x0=x(length(x),:);
[tempo,x] = ode23('modello_SEIR',[0 Tfin],x0,opt);
S=exp(x(:,1));  % suscettibili
E=exp(x(:,2));  % esposti
I=exp(x(:,3));  % infetti
figure; semilogy(tempo,100*I);
xlabel('t'); ylabel('%I');
text(4,0.5,'\delta=0.02','FontSize',16);
ax = gca; ax.FontSize=15;
axis([0 10 0.015 0.025]);
text(8,0.023,'\delta=0.02','FontSize',16);
pause;
figure; semilogy(100*S,100*I);
xlabel('%S'); ylabel('%I')
ax = gca; ax.FontSize=15;
axis([5.2600    5.36    0.016    0.023]);
text(5.34,0.022,'\delta=0.02','FontSize',16);
pause;
% mappa di Poincar
Smap=[]; Imap=[];
for k=1:Tfin
    indice=find(tempo>=k);
    Smap=[Smap;S(indice(1))]; Imap=[Imap;I(indice(1))];
end
figure; semilogy(100*Smap,100*Imap,'b.','MarkerSize',8);
xlabel('%S'); ylabel('%I'); axis([100*0.02 100*0.1 100*10^(-7) 100*0.01]);
ax = gca; ax.FontSize=15; 
text(8,0.1,'\delta=0.02','FontSize',16);
pause;
% 
% % ciclo di periodo 2
delta=0.1;
Tfin=100;
x0vere=[0.5 0.01 0.01 1 0];
x0=[log(x0vere(1)) log(x0vere(2)) log(x0vere(3)) x0vere(4) x0vere(5)];
% transitorio
[tempo,x] = ode23('modello_SEIR',[0 Tfin*3],x0,opt);
% attrattore
x0=x(length(x),:);
[tempo,x] = ode23('modello_SEIR',[0 Tfin],x0,opt);
S=exp(x(:,1));  % suscettibili
E=exp(x(:,2));  % esposti
I=exp(x(:,3));  % infetti
figure; semilogy(tempo,100*I);
xlabel('t'); ylabel('%I');
ax = gca; ax.FontSize=15;
axis([0  20.0000    0.004    0.1100]);
text(17,0.09,'\delta=0.1','FontSize',16);
pause;
figure; semilogy(100*S,100*I);
xlabel('%S'); ylabel('%I');
ax = gca; ax.FontSize=15;
axis([4.3    6.2    0.003    0.110]);
text(5.8,0.08,'\delta=0.1','FontSize',16);
pause;
% mappa di Poincar
Smap=[]; Imap=[];
for k=1:Tfin
    indice=find(tempo>=k);
    Smap=[Smap;S(indice(1))]; Imap=[Imap;I(indice(1))];
end
figure; semilogy(100*Smap,100*Imap,'b.','MarkerSize',4);
xlabel('%S'); ylabel('%I');
ax = gca; ax.FontSize=15;
axis([5.0000    6.0000    0.003   0.04]);
text(5.1,3*10^(-2),'\delta=0.1','FontSize',16);
pause;
 
% ciclo di periodo 4
delta=0.24;
Tfin=100;
x0vere=[0.5 0.01 0.01 1 0];
x0=[log(x0vere(1)) log(x0vere(2)) log(x0vere(3)) x0vere(4) x0vere(5)];
% transitorio
[tempo,x] = ode23('modello_SEIR',[0 Tfin*3],x0,opt);
% attrattore
x0=x(length(x),:);
[tempo,x] = ode23('modello_SEIR',[0 Tfin],x0,opt);
S=exp(x(:,1));  % suscettibili
E=exp(x(:,2));  % esposti
I=exp(x(:,3));  % infetti
figure; semilogy(tempo,100*I);
xlabel('t'); ylabel('%I'); axis([0 15 100*10^(-6) 100*10^(-2)]);
text(12,0.5,'\delta=0.24','FontSize',16);
ax = gca; ax.FontSize=15;
pause;
figure; semilogy(100*S,100*I);
xlabel('%S'); ylabel('%I'); axis([4 7 0.0005 0.15]);
ax = gca; ax.FontSize=15;
text(6.4,0.1,'\delta=0.24','FontSize',16);
pause;
% mappa di Poincar
Smap=[]; Imap=[];
for k=1:Tfin
    indice=find(tempo>=k);
    Smap=[Smap;S(indice(1))]; Imap=[Imap;I(indice(1))];
end
figure; semilogy(100*Smap,100*Imap,'b.','MarkerSize',4);
xlabel('%S'); ylabel('%I'); axis([100*0.02 100*0.1 100*10^(-7) 100*0.01]);
ax = gca; ax.FontSize=15;
text(8,0.4,'\delta=0.24','FontSize',16);
pause;
% 
% caos
delta=0.255;
Tfin=400;
x0vere=[0.5 0.01 0.01 1 0];
x0=[log(x0vere(1)) log(x0vere(2)) log(x0vere(3)) x0vere(4) x0vere(5)];
% transitorio
[tempo,x] = ode23('modello_SEIR',[0 Tfin*0.5],x0,opt);
% attrattore
x0=x(length(x),:);
[tempo,x] = ode23('modello_SEIR',[0 Tfin],x0,opt);
S=exp(x(:,1));  % suscettibili
E=exp(x(:,2));  % esposti
I=exp(x(:,3));  % infetti
figure; plot(tempo,100*I);
xlabel('t'); ylabel('%I');
ax = gca; ax.FontSize=15;
axis([0 100 0 0.35]);
text(80,0.3,'\delta=0.255','FontSize',16);
pause;
figure; semilogy(S*100,I*100);
xlabel('%S'); ylabel('%I');
ax = gca; ax.FontSize=15;
text(8,10^(-9),'\delta=0.255','FontSize',16);
pause;
% mappa di Poincar
Smap=[]; Imap=[];
for k=1:Tfin
    indice=find(tempo>=k);
    Smap=[Smap;S(indice(1))]; Imap=[Imap;I(indice(1))];
end
figure; semilogy(100*Smap,100*Imap,'b.','MarkerSize',4);
xlabel('%S'); ylabel('%I'); axis([100*0.02 100*0.1 100*10^(-12) 100*0.01]);
ax = gca; ax.FontSize=15;
text(8,10^(-9),'\delta=0.255','FontSize',16);


