% simulazione del modello del pendolo doppio
clear all; close all;

% parametri, variabile di stato e orizzonte di simulazione
global omega2;
global x0;
global Tfin;

g=9.81;

l=0.5; omega2=g/l;
Tfin=50; x0=[pi/2 -3*pi/4 0 0];
[tempo,x] = ode45('modello_pendolo_doppio',[0:Tfin/3000:Tfin],x0);

x1=l*sin(x(:,1));
y1=l*(2-cos(x(:,1)));
x2=l*(sin(x(:,1))+sin(x(:,2)));
y2=l*(2-cos(x(:,1))-cos(x(:,2)));
xcerniera=zeros(length(x1),1);
ycerniera=l*2*ones(length(x1),1);

%%%%% POSIZIONE DELLE MASSE NEL TEMPO %%%%%
figure(1); plot(tempo,x1,tempo,x2);
axis([0 30 -2*l 2*l]);
xlabel('tempo'); ylabel('posizione delle masse');
ax = gca;
ax.FontSize=15;
pause;

%%%%% ANIMAZIONE %%%%%
figure(2); hold on;
axis([-2*l-0.01 2*l+0.01 -0.01 4*0.85*l]);
for k = 2:floor(0.15*length(x1))
    plot([x1(k) x2(k)],[y1(k) y2(k)],'k',[xcerniera(k) x1(k)],[ycerniera(k) y1(k)],'k')
         plot(xcerniera(k),ycerniera(k),'b.','MarkerSize',10)
         plot(x1(k),y1(k),'r.','MarkerSize',10)
         plot(x2(k),y2(k),'r.','MarkerSize',10)
    plot([x1(k-1) x2(k-1)],[y1(k-1) y2(k-1)],'w',[xcerniera(k-1) x1(k-1)],[ycerniera(k-1) y1(k-1)],'w')
         plot(x1(k-1),y1(k-1),'w.','MarkerSize',10)
         plot(x2(k-1),y2(k-1),'w.','MarkerSize',10)
    plot([x1(k) x2(k)],[y1(k) y2(k)],'k',[xcerniera(k) x1(k)],[ycerniera(k) y1(k)],'k')
         plot(x1(k),y1(k),'r.','MarkerSize',10)
         plot(x2(k),y2(k),'r.','MarkerSize',10)
    pause(0.01);
    if k==2
        pause
    end
end
pause;

%%%%% ANIMAZIONE CON TRAIETTORIA DELLA SECONDA MASSA %%%%%
figure(3); hold on;
axis([-2*l-0.01 2*l+0.01 -0.01 4*0.85*l]);
for k = 2:floor(0.15*length(x1))
    plot([x1(k) x2(k)],[y1(k) y2(k)],'k',[xcerniera(k) x1(k)],[ycerniera(k) y1(k)],'k')
         plot(x2(1:k),y2(1:k),'k')
         plot(x2(k),y2(k),'k.','MarkerSize',10)
    plot([x1(k-1) x2(k-1)],[y1(k-1) y2(k-1)],'w',[xcerniera(k-1) x1(k-1)],[ycerniera(k-1) y1(k-1)],'w')
         plot(x2(k-1),y2(k-1),'w.','MarkerSize',10)
    plot([x1(k) x2(k)],[y1(k) y2(k)],'k',[xcerniera(k) x1(k)],[ycerniera(k) y1(k)],'k')
         plot(x2(1:k),y2(1:k),'k')
         plot(x2(k),y2(k),'k.','MarkerSize',10)
    pause(0.01);
end
pause;

%%%%% ANIMAZIONE CON TRAIETTORIA DELLA SECONDA MASSA - SENSITIVITA' ALLE CONDIZIONI INIZIALI %%%%%
epsilon=0.01;
Tfin=50; x0NEW=[pi/2*(1-epsilon) -3*pi/4 0 0];
[tempoNEW,xNEW] = ode45('modello_pendolo_doppio',[0:Tfin/3000:Tfin],x0NEW);
x1NEW=l*sin(xNEW(:,1));
y1NEW=l*(2-cos(xNEW(:,1)));
x2NEW=l*(sin(xNEW(:,1))+sin(xNEW(:,2)));
y2NEW=l*(2-cos(xNEW(:,1))-cos(xNEW(:,2)));
xcernieraNEW=zeros(length(x1NEW),1);
ycernieraNEW=l*2*ones(length(x1NEW),1);

figure(4); hold on;
axis([-2*l-0.01 2*l+0.01 -0.01 4*0.85*l]);
for k = 2:floor(0.15*length(x1NEW))
    % condizioni nominali
    plot([x1(k) x2(k)],[y1(k) y2(k)],'k',[xcerniera(k) x1(k)],[ycerniera(k) y1(k)],'k')
         plot(x2(1:k),y2(1:k),'k')
         plot(x2(k),y2(k),'k.','MarkerSize',10)
    plot([x1(k-1) x2(k-1)],[y1(k-1) y2(k-1)],'w',[xcerniera(k-1) x1(k-1)],[ycerniera(k-1) y1(k-1)],'w')
         plot(x2(k-1),y2(k-1),'w.','MarkerSize',10)
    plot([x1(k) x2(k)],[y1(k) y2(k)],'k',[xcerniera(k) x1(k)],[ycerniera(k) y1(k)],'k')
         plot(x2(1:k),y2(1:k),'k')
         plot(x2(k),y2(k),'k.','MarkerSize',10)
    if k==2
        pause
    end
    % condizioni perturbate
    plot([x1NEW(k) x2NEW(k)],[y1NEW(k) y2NEW(k)],'r',[xcernieraNEW(k) x1NEW(k)],[ycernieraNEW(k) y1NEW(k)],'r')
         plot(x2NEW(1:k),y2NEW(1:k),'r')
         plot(x2NEW(k),y2NEW(k),'r.','MarkerSize',10)
    plot([x1NEW(k-1) x2NEW(k-1)],[y1NEW(k-1) y2NEW(k-1)],'w',[xcernieraNEW(k-1) x1NEW(k-1)],[ycernieraNEW(k-1) y1NEW(k-1)],'w')
         plot(x2NEW(k-1),y2NEW(k-1),'w.','MarkerSize',10)
    plot([x1NEW(k) x2NEW(k)],[y1NEW(k) y2NEW(k)],'r',[xcernieraNEW(k) x1NEW(k)],[ycernieraNEW(k) y1NEW(k)],'r')
         plot(x2NEW(1:k),y2NEW(1:k),'r')
         plot(x2NEW(k),y2NEW(k),'r.','MarkerSize',10)
    if k==2
        pause
    end
    pause(0.01);
end
pause;

%%%%%% TRACCIATO xy %%%%%
figure(5); hold on;
axis([-2*l-0.01 2*l+0.01 -0.01 4*l]);
plot(x2,y2,'k')
pause;
plot(x2NEW,y2NEW,'r')
pause;

%%%%%% ANIMAZIONE %%%%%
figure(6); hold on;
axis([-2*l-0.01 2*l+0.01 -0.01 4*0.85*l]);
for k = 2:floor(0.3*length(x1))
    plot([x1(k) x2(k)],[y1(k) y2(k)],[xcerniera(k) x1(k)],[ycerniera(k) y1(k)],'LineWidth',2)
    plot([x1(k-1) x2(k-1)],[y1(k-1) y2(k-1)],'w',[xcerniera(k-1) x1(k-1)],[ycerniera(k-1) y1(k-1)],'w')
    pause(0.01);
end

%%%%%%%%%%%%%%%%%%%%%% ALTRO MATERIALE %%%%%%%%%%%%%%%%%%%%

% h = animatedline('MaximumNumPoints',2,'Marker','o','MarkerSize',4,'MarkerFaceColor','g','MarkerEdgeColor','g');
% for k = 1:length(x1)
%     addpoints(h,xcerniera(k),ycerniera(k)); hold on;
%     drawnow
%     addpoints(h,x1(k),y1(k)); hold on;
%     drawnow
%     addpoints(h,x2(k),y2(k));
%     drawnow
% end

